@@ -178,6 +178,7 @@ class LasReaderTestCase(unittest.TestCase):
 class LasWriterTestCase(unittest.TestCase):
     simple = './laspytest/data/simple.las'
     tempfile = 'writer.las'
+    output_tempfile = 'writer_output.las'
     def setUp(self):
         shutil.copyfile(self.simple, self.tempfile)  
         self.FileObject = File.File(self.tempfile, mode = "rw")
@@ -303,7 +304,12 @@ class LasWriterTestCase(unittest.TestCase):
         self.FileObject.blue = b1
         b2 = self.FileObject.get_blue()
         self.assertTrue((b1 == list(b2)))
-
+    def test_vlr_defined_dimensions2(self):
+        File2 = File.File(self.output_tempfile, mode = "w", header = self.FileObject.header)
+        File2.define_new_dimension("test_dimension", 5, "This is a test.")
+        File2.X = self.FileObject.X
+        self.assertTrue(File2.test_dimension[500] == 0)
+        File2.close(ignore_header_changes = True)
     #def test_wave_pkt_descp_idx(self):
     #    w1 = self.FileObject.wave_packet_descp_idx + 1
     #    self.FileObject.wave_packet_descp_idx = w1
@@ -649,6 +655,7 @@ class LasV_14TestCase(unittest.TestCase):
         File2.classification = classification
         File2.classification_flags = classification_flags
         File2.scan_dir_flag = scan_dir_flag
+        File2.scanner_channel = scanner_channel
         File2.edge_flight_line = edge_flight_line
         File2.return_num = return_num
         File2.num_returns = num_returns
@@ -659,11 +666,43 @@ class LasV_14TestCase(unittest.TestCase):
         self.assertTrue(all(scan_dir_flag ==File2.get_scan_dir_flag() )) 
         self.assertTrue(all(classification_flags == File2.get_classification_flags())) 
         self.assertTrue(all(classification == File2.get_classification())) 
+        self.assertTrue(all(scanner_channel == File2.get_scanner_channel()))
         File2.close(ignore_header_changes = True)
     def tearDown(self):
         self.File1.close()
         os.remove(self.tempfile)
 
+    def test_vlr_defined_dimensions(self):
+        new_header = self.File1.header.copy()
+        # Test basic numeric dimension
+        new_dim_record1 = header.ExtraBytesStruct(name = "Test Dimension 1234", data_type = 5) 
+        # Test string dimension (len 3)
+        new_dim_record2 = header.ExtraBytesStruct(name = "Test Dimension 5678", data_type = 22)
+        # Test integer array dimension (len 3)
+        new_dim_record3 = header.ExtraBytesStruct(name = "Test Dimension 9", data_type =  26) 
+        new_VLR_rec = header.VLR(user_id = "LASF_Spec", record_id = 4, 
+                VLR_body = (new_dim_record1.to_byte_string() + new_dim_record2.to_byte_string() + new_dim_record3.to_byte_string()))
+        new_header.data_record_length += (19)
+        File2 = File.File(self.output_tempfile, mode = "w", header = new_header, vlrs = [new_VLR_rec], evlrs = self.File1.header.evlrs)
+
+        File2.X = self.File1.X
+
+        File2._writer.set_dimension("test_dimension_1234", [4]*len(self.File1))
+        File2._writer.set_dimension("test_dimension_5678", ["AAA"]*len(self.File1))
+        File2._writer.set_dimension("test_dimension_9", [[1,2,3]]*len(self.File1))
+        self.assertTrue(all(np.array(["AAA"]*len(self.File1)) == File2.test_dimension_5678))
+        self.assertTrue(all(np.array([4]*len(self.File1)) == File2.test_dimension_1234))
+        self.assertTrue(list(File2.test_dimension_9[100]) == [1,2,3])
+        File2.close(ignore_header_changes = True)
+
+
+    def test_vlr_defined_dimensions2(self):
+        File2 = File.File(self.output_tempfile, mode = "w", header = self.File1.header)
+        File2.define_new_dimension("test_dimension", 5, "This is a test.")
+        File2.X = self.File1.X
+        self.assertTrue(File2.test_dimension[500] == 0)
+        File2.close(ignore_header_changes = True)
+
 
 
 def test_laspy():
